@@ -3,7 +3,7 @@ package Module::Lazy;
 use 5.008;
 use strict;
 use warnings;
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 =head1 NAME
 
@@ -63,6 +63,8 @@ No extra options (except from target module name) are allowed.
 =cut
 
 my %seen;
+my $inc_stub = "pending load by ".__PACKAGE__;
+
 sub import {
     my ($class, $target, @rest) = @_;
 
@@ -81,20 +83,24 @@ sub import {
 
     $seen{$target} = $mod;
 
-    our $AUTOLOAD;
+    # If $target is later require'd directly,
+    # autoload and destroy will be overwritten and will cause a warning.
+    # Preventing them from being loaded seems like a lesser evil.
+    $INC{$mod} = $inc_stub;
+
     _set_function( $target, AUTOLOAD => sub {
-        _load( $target );
+        our $AUTOLOAD;
+        $AUTOLOAD =~ s/.*:://;
         my $jump = _jump( $target, $AUTOLOAD );
         goto $jump;
     } );
 
+    # Provide DESTROY just in case someone blesses an object directly
+    #     without ever loading a module
+    _set_function( $target, DESTROY => _jump( $target, DESTROY => "no_die" ) );
+
     foreach (qw( can isa )) {
-        my $name = $_; # separate variable to close over
-        _set_function( $target, $name => sub {
-            _load( $target );
-            my $jump = _jump( $target, $name );
-            goto $jump;
-        });
+        _set_function( $target, $_ => _jump( $target, $_ ) );
     };
 };
 
@@ -127,15 +133,22 @@ my %known_method;
 sub _load {
     my $target = shift;
 
+    # TODO distinguish between "not seen" and "already loaded"
     my $mod = delete $seen{$target};
     croak "Module '$target' was never loaded via Module::Lazy, that's possibly a bug"
         unless $mod;
 
+    croak "Module '$target' already loaded from '$INC{$mod}'"
+        unless $INC{$mod} and $INC{$mod} eq $inc_stub;
+
     # reset stub methods prior to loading
     foreach (keys %{ $known_method{$target} || {} }) {
         _set_function( $target, $_ => undef );
     };
 
+    # make the module loadable again
+    delete $INC{$mod};
+
     package
         Module::Lazy::_::quarantine;
 
@@ -147,13 +160,16 @@ sub _load {
 sub _jump {
     my ($target, $todo, $nodie) = @_;
 
-    $todo =~ s/.*:://;
-    my $jump = $target->can($todo);
+    return sub {
+        _load( $target );
 
-    croak qq{Can't locate object method "$todo" via package "$target"}
-        unless $jump or $nodie;
+        my $jump = $target->can($todo);
+        goto $jump
+            if $jump; # TODO should also check it's a CODEREF
 
-    return $jump;
+        croak qq{Can't locate object method "$todo" via package "$target"}
+            unless $nodie;
+    };
 };
 
 sub _set_function {
